==> sagcad-0.9.4.tar.gz: sagcad-0.9.4/src/LineStyleBox.h <==
/* ====================================================================
 * ===  Copyright (C) 1998-2002 Yutaka Sagiya. All rights reserved. ===
 * ====================================================================
 * 
 *    Project              : sagcad
 *    Description          : CAD/CAM
 *    Source               : LineStyleBox.h
 * 
 *    ----------------------------------
 * 
 *    License              : GNU General Public License (GPL)
 *    Copyright            : (C) 1998-2002 by Yutaka Sagiya
 *    email                : kappa@a6s.highway.ne.jp
 *                         : yutaka@sagiya.com
 *    Begin                : 2001/01/16
 *    Last                 : 2002/06/25
 * ====================================================================
 */

#ifndef __LINESTYLEBOX_H__
#define __LINESTYLEBOX_H__
/*
 * -------------------------------------------------------
 * 1 :   (struct #define etc)
 * -------------------------------------------------------
 */



/*
 * -------------------------------------------------------
 * 2 : ѿ
 * -------------------------------------------------------
 */
/* draw.c ƤФ줿Ȥ */
#ifdef LINESTYLEBOX 



/* draw.c ʳƤФ줿Ȥ */
#else 



#endif /* LINESTYLEBOX */
#undef LINESTYLEBOX


/*
 * -------------------------------------------------------
 * 3 : ؿ
 * -------------------------------------------------------
 */
GtkWidget *create_line_style_box(void);



#endif /* __LINESTYLEBOX_H__ */



/* ====================================================================
 * ===  Copyright (C) 1998-2002 Yutaka Sagiya. All rights reserved. ===
 * ====================================================================
 *    Project              : sagcad
 *    Description          : CAD/CAM
 *    Source               : LineStyleBox.h
 * ====================================================================
 */

==> sagcad-0.9.11.tar.gz: sagcad-0.9.11/src/LineStyleBox.h <==
/* ====================================================================
 * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
 * ====================================================================
 * 
 *    Project              : sagcad
 *    Description          : CAD/CAM
 *    Source               : LineStyleBox.h
 * 
 *    ----------------------------------
 * 
 *    License              : GNU General Public License (GPL)
 *    Copyright            : (C) 1998-2007 by Yutaka Sagiya
 *    email                : kappa@a6s.highway.ne.jp
 *                         : yutaka@sagiya.com
 *    Begin                : 2001/01/16
 *    Last                 : 2007/10/24
 * ====================================================================
 */

#ifndef __LINESTYLEBOX_H__
#define __LINESTYLEBOX_H__
/*
 * -------------------------------------------------------
 * 1 : 前処理  (struct #define etc)
 * -------------------------------------------------------
 */



/*
 * -------------------------------------------------------
 * 2 : 外部変数
 * -------------------------------------------------------
 */
/* draw.c から呼ばれたとき */
#ifdef LINESTYLEBOX 



/* draw.c 以外から呼ばれたとき */
#else 



#endif /* LINESTYLEBOX */
#undef LINESTYLEBOX


/*
 * -------------------------------------------------------
 * 3 : 外部関数
 * -------------------------------------------------------
 */
GtkWidget *create_line_style_box(void);



#endif /* __LINESTYLEBOX_H__ */



/* ====================================================================
 * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
 * ====================================================================
 *    Project              : sagcad
 *    Description          : CAD/CAM
 *    Source               : LineStyleBox.h
 * ====================================================================
 */
